@@ -525,7 +525,9 @@ func (nsc *NetworkServicesController) cleanupStaleIPVSConfig(activeServiceEndpoi
 		// Note that this isn't all that safe of an assumption because FWMark services have a completely different
 		// protocol. So do SCTP services. However, we don't deal with SCTP in kube-router and FWMark is handled below.
 		protocol = convertSysCallProtoToSvcProto(ipvsSvc.Protocol)
-		if protocol == noneProtocol {
+		// FWMark services by definition don't have a protocol, so we exclude those from the conditional so that they
+		// can be cleaned up correctly.
+		if protocol == noneProtocol && ipvsSvc.FWMark == 0 {
 			klog.Warningf("failed to convert protocol %d to a valid IPVS protocol for service: %s skipping",
 				ipvsSvc.Protocol, ipvsSvc.Address.String())
 			continue
@@ -624,7 +626,6 @@ func (nsc *NetworkServicesController) cleanupDSRService(fwMark uint32) error {
 
 	// All of the iptables-save output here prints FW marks in hexadecimal, if we are doing string searching, our search
 	// input needs to be in hex also
-	// nolint:gomnd // we're converting to hex here, we don't need to track this as a constant
 	fwMarkStr := strconv.FormatInt(int64(fwMark), 16)
 	for _, mangleTableRule := range mangleTableRules {
 		if strings.Contains(mangleTableRule, ipAddress) && strings.Contains(mangleTableRule, fwMarkStr) {
