@@ -9,7 +9,7 @@ import (
 	"strconv"
 	"strings"
 
-	gobgpapi "github.com/osrg/gobgp/api"
+	gobgpapi "github.com/osrg/gobgp/v3/api"
 	v1core "k8s.io/api/core/v1"
 	"k8s.io/klog/v2"
 
@@ -391,7 +391,7 @@ func (nrc *NetworkRoutingController) addAllBGPPeersDefinedSet(iBGPPeerCIDRs, ext
 	if err != nil {
 		return err
 	}
-	// nolint:gocritic // We intentionally append to a different array here so as to not change the passed
+	//nolint:gocritic // We intentionally append to a different array here so as to not change the passed
 	// in externalBGPPeerCIDRs
 	allBgpPeers := append(externalBGPPeerCIDRs, iBGPPeerCIDRs...)
 	if currentDefinedSet == nil {
@@ -451,19 +451,19 @@ func (nrc *NetworkRoutingController) addAllBGPPeersDefinedSet(iBGPPeerCIDRs, ext
 
 // BGP export policies are added so that following conditions are met:
 //
-// - by default export of all routes from the RIB to the neighbour's is denied, and explicitly statements are added
-//   to permit the desired routes to be exported
-// - each node is allowed to advertise its assigned pod CIDR's to all of its iBGP peer neighbours with same
-//   ASN if --enable-ibgp=true
-// - each node is allowed to advertise its assigned pod CIDR's to all of its external BGP peer neighbours
-//   only if --advertise-pod-cidr flag is set to true
-// - each node is NOT allowed to advertise its assigned pod CIDR's to all of its external BGP peer neighbours
-//   only if --advertise-pod-cidr flag is set to false
-// - each node is allowed to advertise service VIP's (cluster ip, load balancer ip, external IP) ONLY to external
-//   BGP peers
-// - each node is NOT allowed to advertise service VIP's (cluster ip, load balancer ip, external IP) to
-//   iBGP peers
-// - an option to allow overriding the next-hop-address with the outgoing ip for external bgp peers
+//   - by default export of all routes from the RIB to the neighbour's is denied, and explicitly statements are added
+//     to permit the desired routes to be exported
+//   - each node is allowed to advertise its assigned pod CIDR's to all of its iBGP peer neighbours with same
+//     ASN if --enable-ibgp=true
+//   - each node is allowed to advertise its assigned pod CIDR's to all of its external BGP peer neighbours
+//     only if --advertise-pod-cidr flag is set to true
+//   - each node is NOT allowed to advertise its assigned pod CIDR's to all of its external BGP peer neighbours
+//     only if --advertise-pod-cidr flag is set to false
+//   - each node is allowed to advertise service VIP's (cluster ip, load balancer ip, external IP) ONLY to external
+//     BGP peers
+//   - each node is NOT allowed to advertise service VIP's (cluster ip, load balancer ip, external IP) to
+//     iBGP peers
+//   - an option to allow overriding the next-hop-address with the outgoing ip for external bgp peers
 func (nrc *NetworkRoutingController) addExportPolicies() error {
 	statements := make([]*gobgpapi.Statement, 0)
 
@@ -493,12 +493,12 @@ func (nrc *NetworkRoutingController) addExportPolicies() error {
 			&gobgpapi.Statement{
 				Conditions: &gobgpapi.Conditions{
 					PrefixSet: &gobgpapi.MatchSet{
-						MatchType: gobgpapi.MatchType_ANY,
-						Name:      "podcidrdefinedset",
+						Type: gobgpapi.MatchSet_ANY,
+						Name: "podcidrdefinedset",
 					},
 					NeighborSet: &gobgpapi.MatchSet{
-						MatchType: gobgpapi.MatchType_ANY,
-						Name:      "iBGPpeerset",
+						Type: gobgpapi.MatchSet_ANY,
+						Name: "iBGPpeerset",
 					},
 				},
 				Actions: &actions,
@@ -515,7 +515,7 @@ func (nrc *NetworkRoutingController) addExportPolicies() error {
 		// set BGP communities for the routes advertised to peers for VIPs
 		if len(nrc.nodeCommunities) > 0 {
 			bgpActions.Community = &gobgpapi.CommunityAction{
-				ActionType:  gobgpapi.CommunityActionType_COMMUNITY_ADD,
+				Type:        gobgpapi.CommunityAction_ADD,
 				Communities: nrc.nodeCommunities,
 			}
 		}
@@ -525,12 +525,12 @@ func (nrc *NetworkRoutingController) addExportPolicies() error {
 		statements = append(statements, &gobgpapi.Statement{
 			Conditions: &gobgpapi.Conditions{
 				PrefixSet: &gobgpapi.MatchSet{
-					MatchType: gobgpapi.MatchType_ANY,
-					Name:      "servicevipsdefinedset",
+					Type: gobgpapi.MatchSet_ANY,
+					Name: "servicevipsdefinedset",
 				},
 				NeighborSet: &gobgpapi.MatchSet{
-					MatchType: gobgpapi.MatchType_ANY,
-					Name:      "externalpeerset",
+					Type: gobgpapi.MatchSet_ANY,
+					Name: "externalpeerset",
 				},
 			},
 			Actions: &bgpActions,
@@ -543,7 +543,7 @@ func (nrc *NetworkRoutingController) addExportPolicies() error {
 			// set BGP communities for the routes advertised to peers for the pod network
 			if len(nrc.nodeCommunities) > 0 {
 				actions.Community = &gobgpapi.CommunityAction{
-					ActionType:  gobgpapi.CommunityActionType_COMMUNITY_ADD,
+					Type:        gobgpapi.CommunityAction_ADD,
 					Communities: nrc.nodeCommunities,
 				}
 			}
@@ -553,12 +553,12 @@ func (nrc *NetworkRoutingController) addExportPolicies() error {
 			statements = append(statements, &gobgpapi.Statement{
 				Conditions: &gobgpapi.Conditions{
 					PrefixSet: &gobgpapi.MatchSet{
-						MatchType: gobgpapi.MatchType_ANY,
-						Name:      "podcidrdefinedset",
+						Type: gobgpapi.MatchSet_ANY,
+						Name: "podcidrdefinedset",
 					},
 					NeighborSet: &gobgpapi.MatchSet{
-						MatchType: gobgpapi.MatchType_ANY,
-						Name:      "externalpeerset",
+						Type: gobgpapi.MatchSet_ANY,
+						Name: "externalpeerset",
 					},
 				},
 				Actions: &actions,
@@ -622,8 +622,8 @@ func (nrc *NetworkRoutingController) addExportPolicies() error {
 }
 
 // BGP import policies are added so that the following conditions are met:
-// - do not import Service VIPs advertised from any peers, instead each kube-router originates and injects
-//   Service VIPs into local rib.
+//   - do not import Service VIPs advertised from any peers, instead each kube-router originates and injects
+//     Service VIPs into local rib.
 func (nrc *NetworkRoutingController) addImportPolicies() error {
 	statements := make([]*gobgpapi.Statement, 0)
 
@@ -633,12 +633,12 @@ func (nrc *NetworkRoutingController) addImportPolicies() error {
 	statements = append(statements, &gobgpapi.Statement{
 		Conditions: &gobgpapi.Conditions{
 			PrefixSet: &gobgpapi.MatchSet{
-				MatchType: gobgpapi.MatchType_ANY,
-				Name:      "servicevipsdefinedset",
+				Type: gobgpapi.MatchSet_ANY,
+				Name: "servicevipsdefinedset",
 			},
 			NeighborSet: &gobgpapi.MatchSet{
-				MatchType: gobgpapi.MatchType_ANY,
-				Name:      "allpeerset",
+				Type: gobgpapi.MatchSet_ANY,
+				Name: "allpeerset",
 			},
 		},
 		Actions: &actions,
@@ -647,12 +647,12 @@ func (nrc *NetworkRoutingController) addImportPolicies() error {
 	statements = append(statements, &gobgpapi.Statement{
 		Conditions: &gobgpapi.Conditions{
 			PrefixSet: &gobgpapi.MatchSet{
-				MatchType: gobgpapi.MatchType_ANY,
-				Name:      "defaultroutedefinedset",
+				Type: gobgpapi.MatchSet_ANY,
+				Name: "defaultroutedefinedset",
 			},
 			NeighborSet: &gobgpapi.MatchSet{
-				MatchType: gobgpapi.MatchType_ANY,
-				Name:      "allpeerset",
+				Type: gobgpapi.MatchSet_ANY,
+				Name: "allpeerset",
 			},
 		},
 		Actions: &actions,
@@ -662,12 +662,12 @@ func (nrc *NetworkRoutingController) addImportPolicies() error {
 		statements = append(statements, &gobgpapi.Statement{
 			Conditions: &gobgpapi.Conditions{
 				PrefixSet: &gobgpapi.MatchSet{
-					MatchType: gobgpapi.MatchType_ANY,
-					Name:      "customimportrejectdefinedset",
+					Name: "customimportrejectdefinedset",
+					Type: gobgpapi.MatchSet_ANY,
 				},
 				NeighborSet: &gobgpapi.MatchSet{
-					MatchType: gobgpapi.MatchType_ANY,
-					Name:      "allpeerset",
+					Type: gobgpapi.MatchSet_ANY,
+					Name: "allpeerset",
 				},
 			},
 			Actions: &actions,
