@@ -6,14 +6,14 @@ import (
 	"fmt"
 	"strconv"
 
+	"google.golang.org/protobuf/types/known/anypb"
+
+	"github.com/cloudnativelabs/kube-router/pkg/metrics"
 	"github.com/cloudnativelabs/kube-router/pkg/utils"
 
 	"strings"
 
-	// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-	"github.com/golang/protobuf/ptypes"
-	"github.com/golang/protobuf/ptypes/any"
-	gobgpapi "github.com/osrg/gobgp/api"
+	gobgpapi "github.com/osrg/gobgp/v3/api"
 	v1core "k8s.io/api/core/v1"
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/tools/leaderelection/resourcelock"
@@ -26,17 +26,14 @@ func (nrc *NetworkRoutingController) bgpAdvertiseVIP(vip string) error {
 	klog.V(2).Infof("Advertising route: '%s/%s via %s' to peers",
 		vip, strconv.Itoa(32), nrc.nodeIP.String())
 
-	// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-	a1, _ := ptypes.MarshalAny(&gobgpapi.OriginAttribute{
+	a1, _ := anypb.New(&gobgpapi.OriginAttribute{
 		Origin: 0,
 	})
-	// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-	a2, _ := ptypes.MarshalAny(&gobgpapi.NextHopAttribute{
+	a2, _ := anypb.New(&gobgpapi.NextHopAttribute{
 		NextHop: nrc.nodeIP.String(),
 	})
-	attrs := []*any.Any{a1, a2}
-	// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-	nlri1, _ := ptypes.MarshalAny(&gobgpapi.IPAddressPrefix{
+	attrs := []*anypb.Any{a1, a2}
+	nlri1, _ := anypb.New(&gobgpapi.IPAddressPrefix{
 		Prefix:    vip,
 		PrefixLen: 32,
 	})
@@ -48,6 +45,10 @@ func (nrc *NetworkRoutingController) bgpAdvertiseVIP(vip string) error {
 		},
 	})
 
+	if nrc.MetricsEnabled {
+		metrics.ControllerBGPadvertisementsSent.WithLabelValues("advertise-vip").Inc()
+	}
+
 	return err
 }
 
@@ -56,17 +57,14 @@ func (nrc *NetworkRoutingController) bgpWithdrawVIP(vip string) error {
 	klog.V(2).Infof("Withdrawing route: '%s/%s via %s' to peers",
 		vip, strconv.Itoa(32), nrc.nodeIP.String())
 
-	// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-	a1, _ := ptypes.MarshalAny(&gobgpapi.OriginAttribute{
+	a1, _ := anypb.New(&gobgpapi.OriginAttribute{
 		Origin: 0,
 	})
-	// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-	a2, _ := ptypes.MarshalAny(&gobgpapi.NextHopAttribute{
+	a2, _ := anypb.New(&gobgpapi.NextHopAttribute{
 		NextHop: nrc.nodeIP.String(),
 	})
-	attrs := []*any.Any{a1, a2}
-	// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-	nlri, _ := ptypes.MarshalAny(&gobgpapi.IPAddressPrefix{
+	attrs := []*anypb.Any{a1, a2}
+	nlri, _ := anypb.New(&gobgpapi.IPAddressPrefix{
 		Prefix:    vip,
 		PrefixLen: 32,
 	})
@@ -80,6 +78,10 @@ func (nrc *NetworkRoutingController) bgpWithdrawVIP(vip string) error {
 		Path:      &path,
 	})
 
+	if nrc.MetricsEnabled {
+		metrics.ControllerBGPadvertisementsSent.WithLabelValues("withdraw-vip").Inc()
+	}
+
 	return err
 }
 
@@ -167,9 +169,11 @@ func (nrc *NetworkRoutingController) handleServiceDelete(svc *v1core.Service) {
 	for _, activeVIP := range activeVIPs {
 		activeVIPsMap[activeVIP] = true
 	}
-	serviceVIPs := nrc.getAllVIPsForService(svc)
+	advertiseIPList, unadvertiseIPList := nrc.getAllVIPsForService(svc)
+	//nolint:gocritic // we understand that we're assigning to a new slice
+	allIPList := append(advertiseIPList, unadvertiseIPList...)
 	withdrawVIPs := make([]string, 0)
-	for _, serviceVIP := range serviceVIPs {
+	for _, serviceVIP := range allIPList {
 		// withdraw VIP only if deleted service is the last service using the VIP
 		if !activeVIPsMap[serviceVIP] {
 			withdrawVIPs = append(withdrawVIPs, serviceVIP)
@@ -458,39 +462,54 @@ func (nrc *NetworkRoutingController) getVIPsForService(svc *v1core.Service,
 		}
 	}
 
-	ipList := nrc.getAllVIPsForService(svc)
+	advertiseIPList, unAdvertisedIPList := nrc.getAllVIPsForService(svc)
 
 	if !advertise {
-		return nil, ipList, nil
+		//nolint:gocritic // we understand that we're assigning to a new slice
+		allIPList := append(advertiseIPList, unAdvertisedIPList...)
+		return nil, allIPList, nil
 	}
 
-	return ipList, nil, nil
+	return advertiseIPList, unAdvertisedIPList, nil
 }
 
-func (nrc *NetworkRoutingController) getAllVIPsForService(svc *v1core.Service) []string {
+func (nrc *NetworkRoutingController) getAllVIPsForService(svc *v1core.Service) ([]string, []string) {
 
-	ipList := make([]string, 0)
+	advertisedIPList := make([]string, 0)
+	unAdvertisedIPList := make([]string, 0)
 
-	if nrc.shouldAdvertiseService(svc, svcAdvertiseClusterAnnotation, nrc.advertiseClusterIP) {
-		clusterIP := nrc.getClusterIP(svc)
-		if clusterIP != "" {
-			ipList = append(ipList, clusterIP)
+	clusterIP := nrc.getClusterIP(svc)
+	if clusterIP != "" {
+		if nrc.shouldAdvertiseService(svc, svcAdvertiseClusterAnnotation, nrc.advertiseClusterIP) {
+			advertisedIPList = append(advertisedIPList, clusterIP)
+		} else {
+			unAdvertisedIPList = append(unAdvertisedIPList, clusterIP)
 		}
 	}
 
-	if nrc.shouldAdvertiseService(svc, svcAdvertiseExternalAnnotation, nrc.advertiseExternalIP) {
-		ipList = append(ipList, nrc.getExternalIPs(svc)...)
+	externalIPs := nrc.getExternalIPs(svc)
+	if len(externalIPs) > 0 {
+		if nrc.shouldAdvertiseService(svc, svcAdvertiseExternalAnnotation, nrc.advertiseExternalIP) {
+			advertisedIPList = append(advertisedIPList, externalIPs...)
+		} else {
+			unAdvertisedIPList = append(unAdvertisedIPList, externalIPs...)
+		}
 	}
 
 	// Deprecated: Use service.advertise.loadbalancer=false instead of service.skiplbips.
-	_, skiplbips := svc.Annotations[svcSkipLbIpsAnnotation]
-	advertiseLoadBalancer := nrc.shouldAdvertiseService(svc, svcAdvertiseLoadBalancerAnnotation,
-		nrc.advertiseLoadBalancerIP)
-	if advertiseLoadBalancer && !skiplbips {
-		ipList = append(ipList, nrc.getLoadBalancerIPs(svc)...)
+	lbIPs := nrc.getLoadBalancerIPs(svc)
+	if len(lbIPs) > 0 {
+		_, skiplbips := svc.Annotations[svcSkipLbIpsAnnotation]
+		advertiseLoadBalancer := nrc.shouldAdvertiseService(svc, svcAdvertiseLoadBalancerAnnotation,
+			nrc.advertiseLoadBalancerIP)
+		if advertiseLoadBalancer && !skiplbips {
+			advertisedIPList = append(advertisedIPList, lbIPs...)
+		} else {
+			unAdvertisedIPList = append(unAdvertisedIPList, lbIPs...)
+		}
 	}
 
-	return ipList
+	return advertisedIPList, unAdvertisedIPList
 
 }
 
