@@ -5,7 +5,6 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
-	"io/ioutil"
 	"net"
 	"os"
 	"os/exec"
@@ -15,17 +14,15 @@ import (
 	"sync"
 	"time"
 
+	"google.golang.org/protobuf/types/known/anypb"
+
 	"github.com/cloudnativelabs/kube-router/pkg/healthcheck"
 	"github.com/cloudnativelabs/kube-router/pkg/metrics"
 	"github.com/cloudnativelabs/kube-router/pkg/options"
 	"github.com/cloudnativelabs/kube-router/pkg/utils"
 	"github.com/coreos/go-iptables/iptables"
-	"github.com/golang/protobuf/ptypes/any"
-
-	// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-	"github.com/golang/protobuf/ptypes"
-	gobgpapi "github.com/osrg/gobgp/api"
-	gobgp "github.com/osrg/gobgp/pkg/server"
+	gobgpapi "github.com/osrg/gobgp/v3/api"
+	gobgp "github.com/osrg/gobgp/v3/pkg/server"
 	"k8s.io/klog/v2"
 
 	"github.com/prometheus/client_golang/prometheus"
@@ -50,7 +47,8 @@ const (
 	pathPrependRepeatNAnnotation     = "kube-router.io/path-prepend.repeat-n"
 	peerASNAnnotation                = "kube-router.io/peer.asns"
 	peerIPAnnotation                 = "kube-router.io/peer.ips"
-	// nolint:gosec // this is not a hardcoded password
+	peerLocalIPAnnotation            = "kube-router.io/peer.localips"
+	//nolint:gosec // this is not a hardcoded password
 	peerPasswordAnnotation             = "kube-router.io/peer.passwords"
 	peerPortAnnotation                 = "kube-router.io/peer.ports"
 	rrClientAnnotation                 = "kube-router.io/rr.client"
@@ -236,7 +234,7 @@ func (nrc *NetworkRoutingController) Run(healthChan chan<- *healthcheck.Controll
 	}
 
 	if nrc.autoMTU {
-		mtu, err := utils.GetMTUFromNodeIP(nrc.nodeIP, nrc.enableOverlays)
+		mtu, err := utils.GetMTUFromNodeIP(nrc.nodeIP)
 		if err != nil {
 			klog.Errorf("Failed to find MTU for node IP: %s for intelligently setting the kube-bridge MTU "+
 				"due to %s.", nrc.nodeIP, err.Error())
@@ -245,7 +243,18 @@ func (nrc *NetworkRoutingController) Run(healthChan chan<- *healthcheck.Controll
 			klog.Infof("Setting MTU of kube-bridge interface to: %d", mtu)
 			err = netlink.LinkSetMTU(kubeBridgeIf, mtu)
 			if err != nil {
-				klog.Errorf("Failed to set MTU for kube-bridge interface due to: %s", err.Error())
+				klog.Errorf(
+					"Failed to set MTU for kube-bridge interface due to: %s (kubeBridgeIf: %#v, mtu: %v)",
+					err.Error(), kubeBridgeIf, mtu,
+				)
+				// need to correct kuberouter.conf because autoConfigureMTU() may have set an invalid value!
+				currentMTU := kubeBridgeIf.Attrs().MTU
+				if currentMTU > 0 && currentMTU != mtu {
+					klog.Warningf("Updating config file with current MTU for kube-bridge: %d", currentMTU)
+					if err := nrc.configureMTU(currentMTU); err != nil {
+						klog.Errorf("Failed to update config file due to: %s", err.Error())
+					}
+				}
 			}
 		} else {
 			klog.Infof("Not setting MTU of kube-bridge interface")
@@ -402,12 +411,8 @@ func (nrc *NetworkRoutingController) updateCNIConfig() {
 	}
 }
 
-func (nrc *NetworkRoutingController) autoConfigureMTU() error {
-	mtu, err := utils.GetMTUFromNodeIP(nrc.nodeIP, nrc.enableOverlays)
-	if err != nil {
-		return fmt.Errorf("failed to generate MTU: %s", err.Error())
-	}
-	file, err := ioutil.ReadFile(nrc.cniConfFile)
+func (nrc *NetworkRoutingController) configureMTU(mtu int) error {
+	file, err := os.ReadFile(nrc.cniConfFile)
 	if err != nil {
 		return fmt.Errorf("failed to load CNI conf file: %s", err.Error())
 	}
@@ -433,31 +438,47 @@ func (nrc *NetworkRoutingController) autoConfigureMTU() error {
 		pluginConfig["mtu"] = mtu
 	}
 	configJSON, _ := json.Marshal(config)
-	err = ioutil.WriteFile(nrc.cniConfFile, configJSON, 0644)
+	err = os.WriteFile(nrc.cniConfFile, configJSON, 0644)
 	if err != nil {
 		return fmt.Errorf("failed to insert `mtu` into CNI conf file: %s", err.Error())
 	}
 	return nil
 }
 
+func (nrc *NetworkRoutingController) autoConfigureMTU() error {
+	mtu, err := utils.GetMTUFromNodeIP(nrc.nodeIP)
+	if err != nil {
+		return fmt.Errorf("failed to generate MTU: %s", err.Error())
+	}
+	return nrc.configureMTU(mtu)
+}
+
 func (nrc *NetworkRoutingController) watchBgpUpdates() {
-	pathWatch := func(path *gobgpapi.Path) {
-		if nrc.MetricsEnabled {
-			metrics.ControllerBGPadvertisementsReceived.Inc()
-		}
-		if path.NeighborIp == "<nil>" {
-			return
-		}
-		klog.V(2).Infof("Processing bgp route advertisement from peer: %s", path.NeighborIp)
-		if err := nrc.injectRoute(path); err != nil {
-			klog.Errorf("Failed to inject routes due to: " + err.Error())
+	pathWatch := func(r *gobgpapi.WatchEventResponse) {
+		if table := r.GetTable(); table != nil {
+			for _, path := range table.Paths {
+				if path.Family.Afi == gobgpapi.Family_AFI_IP || path.Family.Safi == gobgpapi.Family_SAFI_UNICAST {
+					if nrc.MetricsEnabled {
+						metrics.ControllerBGPadvertisementsReceived.Inc()
+					}
+					if path.NeighborIp == "<nil>" {
+						return
+					}
+					klog.V(2).Infof("Processing bgp route advertisement from peer: %s", path.NeighborIp)
+					if err := nrc.injectRoute(path); err != nil {
+						klog.Errorf("Failed to inject routes due to: " + err.Error())
+					}
+				}
+			}
 		}
 	}
-	err := nrc.bgpServer.MonitorTable(context.Background(), &gobgpapi.MonitorTableRequest{
-		TableType: gobgpapi.TableType_GLOBAL,
-		Family: &gobgpapi.Family{
-			Afi:  gobgpapi.Family_AFI_IP,
-			Safi: gobgpapi.Family_SAFI_UNICAST,
+	err := nrc.bgpServer.WatchEvent(context.Background(), &gobgpapi.WatchEventRequest{
+		Table: &gobgpapi.WatchEventRequest_Table{
+			Filters: []*gobgpapi.WatchEventRequest_Table_Filter{
+				{
+					Type: gobgpapi.WatchEventRequest_Table_Filter_BEST,
+				},
+			},
 		},
 	}, pathWatch)
 	if err != nil {
@@ -467,7 +488,7 @@ func (nrc *NetworkRoutingController) watchBgpUpdates() {
 
 func (nrc *NetworkRoutingController) advertisePodRoute() error {
 	if nrc.MetricsEnabled {
-		metrics.ControllerBGPadvertisementsSent.Inc()
+		metrics.ControllerBGPadvertisementsSent.WithLabelValues("pod-route").Inc()
 	}
 
 	cidrStr := strings.Split(nrc.podCidr, "/")
@@ -483,26 +504,23 @@ func (nrc *NetworkRoutingController) advertisePodRoute() error {
 			Afi:  gobgpapi.Family_AFI_IP6,
 			Safi: gobgpapi.Family_SAFI_UNICAST,
 		}
-		// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-		nlri, _ := ptypes.MarshalAny(&gobgpapi.IPAddressPrefix{
+		nlri, _ := anypb.New(&gobgpapi.IPAddressPrefix{
 			PrefixLen: uint32(cidrLen),
 			Prefix:    cidrStr[0],
 		})
-		// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-		a1, _ := ptypes.MarshalAny(&gobgpapi.OriginAttribute{
+		a1, _ := anypb.New(&gobgpapi.OriginAttribute{
 			Origin: 0,
 		})
-		// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-		v6Attrs, _ := ptypes.MarshalAny(&gobgpapi.MpReachNLRIAttribute{
+		v6Attrs, _ := anypb.New(&gobgpapi.MpReachNLRIAttribute{
 			Family:   v6Family,
 			NextHops: []string{nrc.nodeIP.String()},
-			Nlris:    []*any.Any{nlri},
+			Nlris:    []*anypb.Any{nlri},
 		})
 		_, err := nrc.bgpServer.AddPath(context.Background(), &gobgpapi.AddPathRequest{
 			Path: &gobgpapi.Path{
 				Family: v6Family,
 				Nlri:   nlri,
-				Pattrs: []*any.Any{a1, v6Attrs},
+				Pattrs: []*anypb.Any{a1, v6Attrs},
 			},
 		})
 		if err != nil {
@@ -511,21 +529,18 @@ func (nrc *NetworkRoutingController) advertisePodRoute() error {
 	} else {
 
 		klog.V(2).Infof("Advertising route: '%s/%d via %s' to peers", subnet, cidrLen, nrc.nodeIP.String())
-		// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-		nlri, _ := ptypes.MarshalAny(&gobgpapi.IPAddressPrefix{
+		nlri, _ := anypb.New(&gobgpapi.IPAddressPrefix{
 			PrefixLen: uint32(cidrLen),
 			Prefix:    cidrStr[0],
 		})
 
-		// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-		a1, _ := ptypes.MarshalAny(&gobgpapi.OriginAttribute{
+		a1, _ := anypb.New(&gobgpapi.OriginAttribute{
 			Origin: 0,
 		})
-		// nolint:staticcheck // this has to stick around for now until gobgp updates protobuf
-		a2, _ := ptypes.MarshalAny(&gobgpapi.NextHopAttribute{
+		a2, _ := anypb.New(&gobgpapi.NextHopAttribute{
 			NextHop: nrc.nodeIP.String(),
 		})
-		attrs := []*any.Any{a1, a2}
+		attrs := []*anypb.Any{a1, a2}
 
 		_, err := nrc.bgpServer.AddPath(context.Background(), &gobgpapi.AddPathRequest{
 			Path: &gobgpapi.Path{
@@ -701,10 +716,6 @@ func (nrc *NetworkRoutingController) setupOverlayTunnel(tunnelName string, nextH
 		if err = netlink.LinkSetUp(link); err != nil {
 			return nil, errors.New("Failed to bring tunnel interface " + tunnelName + " up due to: " + err.Error())
 		}
-		// reduce the MTU by 20 bytes to accommodate ipip tunnel overhead
-		if err = netlink.LinkSetMTU(link, link.Attrs().MTU-utils.IPInIPHeaderLength); err != nil {
-			return nil, errors.New("Failed to set MTU of tunnel interface " + tunnelName + " up due to: " + err.Error())
-		}
 	} else {
 		klog.V(1).Infof(
 			"Tunnel interface: " + tunnelName + " for the node " + nextHop.String() + " already exists.")
@@ -714,7 +725,7 @@ func (nrc *NetworkRoutingController) setupOverlayTunnel(tunnelName string, nextH
 	// this interface
 	out, err = exec.Command("ip", "route", "list", "table", customRouteTableID).CombinedOutput()
 	if err != nil || !strings.Contains(string(out), "dev "+tunnelName+" scope") {
-		// nolint:gosec // this exec should be safe from command injection given the parameter's context
+		//nolint:gosec // this exec should be safe from command injection given the parameter's context
 		if out, err = exec.Command("ip", "route", "add", nextHop.String(), "dev", tunnelName, "table",
 			customRouteTableID).CombinedOutput(); err != nil {
 			return nil, fmt.Errorf("failed to add route in custom route table, err: %s, output: %s", err, string(out))
@@ -1036,7 +1047,7 @@ func (nrc *NetworkRoutingController) startBgpServer(grpcServer bool) error {
 	}
 
 	global := &gobgpapi.Global{
-		As:              nodeAsnNumber,
+		Asn:             nodeAsnNumber,
 		RouterId:        nrc.routerID,
 		ListenAddresses: localAddressList,
 		ListenPort:      int32(nrc.bgpPort),
@@ -1120,9 +1131,38 @@ func (nrc *NetworkRoutingController) startBgpServer(grpcServer bool) error {
 			}
 		}
 
+		// Get Global Peer Router LocalIP configs
+		var peerLocalIPs []string
+		nodeBGPPeerLocalIPs, ok := node.ObjectMeta.Annotations[peerLocalIPAnnotation]
+		if !ok {
+			klog.Infof("Could not find BGP peer local ip info in the node's annotations. Assuming node IP.")
+		} else {
+			peerLocalIPs = stringToSlice(nodeBGPPeerLocalIPs, ",")
+			err = func() error {
+				for _, s := range peerLocalIPs {
+					if s != "" {
+						ip := net.ParseIP(s)
+						if ip == nil {
+							return fmt.Errorf("could not parse \"%s\" as an IP", s)
+						}
+					}
+				}
+
+				return nil
+			}()
+			if err != nil {
+				err2 := nrc.bgpServer.StopBgp(context.Background(), &gobgpapi.StopBgpRequest{})
+				if err2 != nil {
+					klog.Errorf("Failed to stop bgpServer: %s", err2)
+				}
+
+				return fmt.Errorf("failed to parse node's Peer Local Addresses Annotation: %s", err)
+			}
+		}
+
 		// Create and set Global Peer Router complete configs
-		nrc.globalPeerRouters, err = newGlobalPeers(peerIPs, peerPorts, peerASNs, peerPasswords, nrc.bgpHoldtime,
-			nrc.nodeIP.String())
+		nrc.globalPeerRouters, err = newGlobalPeers(peerIPs, peerPorts, peerASNs, peerPasswords, peerLocalIPs,
+			nrc.bgpHoldtime, nrc.nodeIP.String())
 		if err != nil {
 			err2 := nrc.bgpServer.StopBgp(context.Background(), &gobgpapi.StopBgpRequest{})
 			if err2 != nil {
@@ -1136,7 +1176,7 @@ func (nrc *NetworkRoutingController) startBgpServer(grpcServer bool) error {
 	}
 
 	if len(nrc.globalPeerRouters) != 0 {
-		err := connectToExternalBGPPeers(nrc.bgpServer, nrc.globalPeerRouters, nrc.bgpGracefulRestart,
+		err := nrc.connectToExternalBGPPeers(nrc.bgpServer, nrc.globalPeerRouters, nrc.bgpGracefulRestart,
 			nrc.bgpGracefulRestartDeferralTime, nrc.bgpGracefulRestartTime, nrc.peerMultihopTTL)
 		if err != nil {
 			err2 := nrc.bgpServer.StopBgp(context.Background(), &gobgpapi.StopBgpRequest{})
@@ -1168,6 +1208,7 @@ func NewNetworkRoutingController(clientset kubernetes.Interface,
 	if kubeRouterConfig.MetricsEnabled {
 		// Register the metrics for this controller
 		prometheus.MustRegister(metrics.ControllerBGPadvertisementsReceived)
+		prometheus.MustRegister(metrics.ControllerBGPadvertisementsSent)
 		prometheus.MustRegister(metrics.ControllerBGPInternalPeersSyncTime)
 		prometheus.MustRegister(metrics.ControllerBPGpeers)
 		prometheus.MustRegister(metrics.ControllerRoutesSyncTime)
@@ -1305,7 +1346,7 @@ func NewNetworkRoutingController(clientset kubernetes.Interface,
 		}
 	} else if len(kubeRouterConfig.PeerPasswordsFile) != 0 {
 		// Contents of the pw file should be in the same format as pw from CLI arg
-		pwFileBytes, err := ioutil.ReadFile(kubeRouterConfig.PeerPasswordsFile)
+		pwFileBytes, err := os.ReadFile(kubeRouterConfig.PeerPasswordsFile)
 		if err != nil {
 			return nil, fmt.Errorf("error loading Peer Passwords File : %s", err)
 		}
@@ -1317,7 +1358,7 @@ func NewNetworkRoutingController(clientset kubernetes.Interface,
 	}
 
 	nrc.globalPeerRouters, err = newGlobalPeers(kubeRouterConfig.PeerRouters, peerPorts,
-		peerASNs, peerPasswords, nrc.bgpHoldtime, nrc.nodeIP.String())
+		peerASNs, peerPasswords, nil, nrc.bgpHoldtime, nrc.nodeIP.String())
 	if err != nil {
 		return nil, fmt.Errorf("error processing Global Peer Router configs: %s", err)
 	}
