@@ -2,7 +2,7 @@ package utils
 
 import (
 	"bytes"
-	// nolint:gosec // we don't use this hash in a sensitive capacity, so we don't care that its weak
+	//nolint:gosec // we don't use this hash in a sensitive capacity, so we don't care that its weak
 	"crypto/sha1"
 	"encoding/base32"
 	"errors"
@@ -10,6 +10,8 @@ import (
 	"os/exec"
 	"sort"
 	"strings"
+
+	"k8s.io/klog/v2"
 )
 
 var (
@@ -184,6 +186,7 @@ func getIPSetPath() (*string, error) {
 func (ipset *IPSet) run(args ...string) (string, error) {
 	var stderr bytes.Buffer
 	var stdout bytes.Buffer
+	klog.V(9).Infof("running ipset command: path=`%s` args=%+v", *ipset.ipSetPath, args)
 	cmd := exec.Cmd{
 		Path:   *ipset.ipSetPath,
 		Args:   append([]string{*ipset.ipSetPath}, args...),
@@ -202,6 +205,8 @@ func (ipset *IPSet) run(args ...string) (string, error) {
 func (ipset *IPSet) runWithStdin(stdin *bytes.Buffer, args ...string) error {
 	var stderr bytes.Buffer
 	var stdout bytes.Buffer
+	klog.V(9).Infof("running ipset command: path=`%s` args=%+v stdin ```%s```",
+		*ipset.ipSetPath, args, stdin.String())
 	cmd := exec.Cmd{
 		Path:   *ipset.ipSetPath,
 		Args:   append([]string{*ipset.ipSetPath}, args...),
@@ -452,7 +457,7 @@ func parseIPSetSave(ipset *IPSet, result string) map[string]*Set {
 			sets[content[1]] = &Set{
 				Parent:  ipset,
 				Name:    content[1],
-				Options: content[2:],
+				Options: scrubInitValFromOptions(content[2:]),
 			}
 		} else if content[0] == "add" {
 			set := sets[content[1]]
@@ -466,6 +471,19 @@ func parseIPSetSave(ipset *IPSet, result string) map[string]*Set {
 	return sets
 }
 
+// scrubInitValFromOptions Remove initval options from save set to help reduce the number of unique options and make
+// ipset restore work faster. The initval is supposed to help restore the exact same set. However, kube-router modifies
+// the sets before it restores it breaking this functionality and causing the restore times to increase significantly.
+// So we remove it when we parse the ipset after a save() call.
+func scrubInitValFromOptions(options []string) []string {
+	for idx, val := range options {
+		if val == "initval" {
+			return append(options[:idx], options[idx+2:]...)
+		}
+	}
+	return options
+}
+
 // Build ipset restore input
 // ex:
 // create KUBE-DST-3YNVZWWGX3UQQ4VQ hash:ip family inet hashsize 1024 maxelem 65536 timeout 0
@@ -488,7 +506,7 @@ func buildIPSetRestore(ipset *IPSet) string {
 		tmpSetName := tmpSets[setOptions]
 		if tmpSetName == "" {
 			// create a temporary set per unique set-options:
-			// nolint:gosec // we don't use this hash in a sensitive capacity, so we don't care that its weak
+			//nolint:gosec // we don't use this hash in a sensitive capacity, so we don't care that its weak
 			hash := sha1.Sum([]byte("tmp:" + setOptions))
 			tmpSetName = tmpIPSetPrefix + base32.StdEncoding.EncodeToString(hash[:10])
 			ipSetRestore.WriteString(fmt.Sprintf("create %s %s\n", tmpSetName, setOptions))
